%fraunhofer_single_slit
% Plots Fraunhofer 'far field' finite width slit diffraction pattern.
% Assume uniformly illuminated.
%
% LAST UPDATED by Andy French 1/11/15

function fraunhofer_single_slit

%Set wavelength /nm
%http://science-edu.larc.nasa.gov/EDDOCS/Wavelengths_for_Colors.html
lamda = 400;  %Violet
lamda = 445;  %Indigo
lamda = 475;  %Blue
lamda = 510;  %Green
lamda = 570;  %Yellow
lamda = 590;  %Orange
lamda = 650;  %Red

%Convert to m
lamda = lamda*1e-9;

%Slit spacing /mm
a = 5*lamda;

%Set fontsize
fsize = 18;

%Wavenumber /m^-1
k = 2*pi/lamda;

%Speed of light /ms^-1
c = 2.998e8;

%Calculate frequency /Hz
f = c/(lamda*1e-9);

%Calculate far-field range limit /m
r_far_field = (a^2)/lamda;

%Set angles
theta = linspace( -pi/2,pi/2,1000);

%Determine intensity pattern amplitude variation with angle (i.e. range is
%the same)
I = ( sinc( 0.5*k*a*sin(theta) ) ).^2;

%Determine angles of maxima
Nmax = floor( 0.5*k*a/pi );
theta_max = NaN(1,2*Nmax+1);
for n=1:2*Nmax+1
    nn = -Nmax-1+n;
    theta_max(n) = asin( 2*nn*pi/(k*a) );
    if ( imag(abs(theta_max(n)))>0 ) || nn==0
        theta_max(n) = NaN;
    end
end

%Plot intensity pattern (i.e. wave power)
plot( theta*180/pi, I );
hold on;
plot( (180/pi)*theta_max,zeros(1,2*Nmax+1),'r*' );
for n=1:2*Nmax+1
    plot( (180/pi)*[theta_max(n),theta_max(n)],[0,1],'r--');
end
xlabel( '\theta^o', 'fontsize',fsize );
ylabel('Normalized wave power','fontsize',fsize )
title(['Fraunhofer far field diffraction: \lambda = ',...
    num2str(lamda*1e9),'nm,  a = ',num2str(a/lamda),'\lambda'],'fontsize',fsize);
xlim([-90,90])
grid on;
set(gca,'fontsize',fsize);
print( gcf,'fraunhofer.png','-dpng','-r300');

%Plot intensity pattern (i.e. wave power)in dB
plot( theta*180/pi, dB(I) );
ylim([-30,0]);
hold on;
plot( (180/pi)*theta_max,zeros(1,2*Nmax+1),'r*' );
for n=1:2*Nmax+1
    plot( (180/pi)*[theta_max(n),theta_max(n)],[-30,0],'r--');
end
xlabel( '\theta^o', 'fontsize',fsize );
ylabel('Normalized wave power /dB','fontsize',fsize )
title(['Fraunhofer far field diffraction: \lambda = ',...
    num2str(lamda*1e9),'nm,  a = ',num2str(a/lamda),'\lambda'],'fontsize',fsize);
xlim([-90,90])
grid on;
set(gca,'fontsize',fsize);
print( gcf,'fraunhofer dB.png','-dpng','-r300');
close(gcf);

%%

function y = sinc(x)
y = ones(size(x));
k = x~=0;
y(k) = sin(x(k))./x((k));

%%

function y = dB(x)
y = NaN(size(x));
k = x>0;
y(k) = 10*log10(x);

%End of code
